@@ -361,6 +361,16 @@ EOF
     fi # End create PV on Bare Metal setup for ETCD
 }
 
+function checking_pg_version() {
+    PG_VERSION=$(kubectl exec -n "$CMS_NAMESPACE" cms-pg-metadata-manager-stolon-keeper-0 -c cms-postgresql -- cat /stolon-data/postgres/PG_VERSION 2>/dev/null | tr -d '\r')
+    if [[ "$PG_VERSION" == "17" ]]; then
+        echo "PG version is 17, skipping upgrade"
+    else
+        echo "Upgrading PG version to 17"
+        python /opt/cms/pg17_upgrade.py -n "$CMS_NAMESPACE"
+    fi
+}
+
 function deploy_products() {
     [[ $1 != "-h" && $1 != "--help" ]] && beginLogging "Start Deploying CMS into cluster."
 
@@ -368,6 +378,7 @@ function deploy_products() {
 
     # Fetch the cms namespace value from products-var.yaml file
     CMS_NAMESPACE=$(grep "^cms_namespace: " $PRODUCTSVAR_FILE|awk -F ':' '{print $2}'|sed -e 's/ //g' -e 's/"//g')
+    checking_pg_version
     
     if [[ ${CLOUDPLATFORM} == "AZURE" ]];then
       # Login to azure to ensure using the expected account and subsciption from the bootstrap node.
